@@ -52,7 +52,7 @@
 #include "upnpapi.h"
 #include "uuid.h"
 
-#ifdef WIN32
+#ifdef _WIN32
 	#define snprintf _snprintf
 #endif
 
@@ -1121,7 +1121,7 @@ void gena_process_subscription_request(
 	SOCKINFO *info,
 	http_message_t *request)
 {
-	struct Upnp_Subscription_Request request_struct;
+	UpnpSubscriptionRequest *request_struct = UpnpSubscriptionRequest_new();
 	Upnp_SID temp_sid;
 	int return_code = 1;
 	int time_out = 1801;
@@ -1138,8 +1138,6 @@ void gena_process_subscription_request(
 	memptr timeout_hdr;
 	int rc = 0;
 
-	memset(&request_struct, 0, sizeof(request_struct));
-
 	UpnpPrintf(UPNP_INFO, GENA, __FILE__, __LINE__,
 		"Subscription Request Received:\n");
 
@@ -1272,7 +1270,7 @@ void gena_process_subscription_request(
 
 	/* generate SID */
 	uuid_create(&uid);
-	uuid_unpack(&uid, temp_sid);
+	upnp_uuid_unpack(&uid, temp_sid);
 	rc = snprintf(sub->sid, sizeof(sub->sid), "uuid:%s", temp_sid);
 
 	/* respond OK */
@@ -1289,10 +1287,9 @@ void gena_process_subscription_request(
 	service->TotalSubscriptions++;
 
 	/* finally generate callback for init table dump */
-	request_struct.ServiceId = service->serviceId;
-	request_struct.UDN = service->UDN;
-	strncpy((char *)request_struct.Sid, sub->sid,
-		sizeof(request_struct.Sid) - 1);
+	UpnpSubscriptionRequest_strcpy_ServiceId(request_struct, service->serviceId);
+	UpnpSubscriptionRequest_strcpy_UDN(request_struct, service->UDN);
+	UpnpSubscriptionRequest_strcpy_SID(request_struct, sub->sid);
 
 	/* copy callback */
 	callback_fun = handle_info->Callback;
@@ -1303,10 +1300,10 @@ void gena_process_subscription_request(
 	/* make call back with request struct */
 	/* in the future should find a way of mainting that the handle */
 	/* is not unregistered in the middle of a callback */
-	callback_fun(UPNP_EVENT_SUBSCRIPTION_REQUEST, &request_struct, cookie);
+	callback_fun(UPNP_EVENT_SUBSCRIPTION_REQUEST, request_struct, cookie);
 
 exit_function:
-	return;
+	UpnpSubscriptionRequest_delete(request_struct);
 }
 
 
